Class: Advantage::a_ads_bind_param_info
- Inherits:
-
Object
- Object
- Advantage::a_ads_bind_param_info
- Defined in:
- ext/advantage/advantage.c
Instance Method Summary collapse
-
#get_info_direction(VALUEbind) ⇒ Object
Gets the name of the bound parameter info object.
-
#get_info_output(VALUEbind) ⇒ Object
Gets the value of a bound parameter after execution.
Instance Method Details
#get_info_direction(VALUEbind) ⇒ Object
Gets the name of the bound parameter info object.
Parameters:
- VALUE bind -- Bound parameter info retrieved from ads_describe_bind_param_info( ).
Returns:
- VALUE direction: The bound variable's direction.
1740 1741 1742 1743 1744 1745 1746 1747 |
# File 'ext/advantage/advantage.c', line 1740
static VALUE
static_Bind_get_info_direction(VALUE bind)
{
a_ads_bind_param_info *s_bind;
Data_Get_Struct(bind, a_ads_bind_param_info, s_bind);
return (CHR2FIX(s_bind->direction));
}
|
#get_info_output(VALUEbind) ⇒ Object
Gets the value of a bound parameter after execution.
Parameters:
- VALUE bind -- Bound parameter retrieved from ads_describe_bind_param( ).
Returns:
- VALUE name: The bound variable value.
1762 1763 1764 1765 1766 1767 1768 |
# File 'ext/advantage/advantage.c', line 1762
static VALUE
static_Bind_get_info_output(VALUE bind)
{
a_ads_bind_param_info *s_bind;
Data_Get_Struct(bind, a_ads_bind_param_info, s_bind);
return (C2RB(&s_bind->output_value));
}
|